// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation.navigator;

import org.apache.log4j.Logger;
import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.Viewer;

import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.taxon.ITreeNode;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;

/**
 * <p>TaxonNodeContentProvider class.</p>
 *
 * @author p.ciardelli
 * @created 02.06.2009
 * @version 1.0
 */
public class TaxonNodeContentProvider implements ITreeContentProvider {
	private static final Logger logger = Logger
			.getLogger(TaxonNodeContentProvider.class);

	private static final Object[] NO_CHILDREN = new Object[0];
	
	/** {@inheritDoc} */
	public Object[] getChildren(Object parentElement) {
		Object[] children = null;		
		
		if(parentElement instanceof ITreeNode){
			ITreeNode treeNode = (ITreeNode) HibernateProxyHelper.deproxy(parentElement);
			children = treeNode.getChildNodes().toArray();
		}
		
		return children != null ? children : NO_CHILDREN;
	}

	/** {@inheritDoc} */
	public Object getParent(Object element) {
		if(element instanceof TaxonNode){
			return ((TaxonNode) element).getParent();
		}		
		return null;
	}

	/** {@inheritDoc} */
	public boolean hasChildren(Object element) {
		if(element instanceof TaxonNode){
			return ((TaxonNode) element).getCountChildren() > 0;
		}
		return getChildren(element).length > 0;
	}

	/** {@inheritDoc} */
	public Object[] getElements(Object inputElement) {
		return this.getChildren(inputElement);
	}

	/**
	 * <p>dispose</p>
	 */
	public void dispose() {
	}

	/** {@inheritDoc} */
	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
	}
}
